package com.example.ueberwachungssystem;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.camera.core.ExperimentalGetImage;
import androidx.camera.view.PreviewView;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ToggleButton;

import com.example.ueberwachungssystem.Detection.DetectionReport;
import com.example.ueberwachungssystem.Detection.DetectorService;

@ExperimentalGetImage
public class MainActivity extends AppCompatActivity {

    private DetectorService detectorService = new DetectorService();
    private ImageView inputImageView;
    private ImageView outputImageView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);


        inputImageView = findViewById(R.id.inputImageView);
        outputImageView = findViewById(R.id.outputImageView);
        PreviewView previewView = findViewById(R.id.previewView);



        Intent serviceIntent = new Intent(this, DetectorService.class);
        bindService(serviceIntent, serviceConnection, Context.BIND_AUTO_CREATE);
        startService(serviceIntent);




        ToggleButton toggleButton = findViewById(R.id.toggleButton);
        toggleButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (toggleButton.isChecked())
                {
                    detectorService.startVideoRecording();
                    //detectorService.startAudioRecording();
                }
                else {
                    //detectorService.stopAudioRecording();
                    detectorService.stopVideoRecording();
                }
            }
        });
    }

    private ServiceConnection serviceConnection = new ServiceConnection() {
        @Override
        public void onServiceConnected(ComponentName name, IBinder service) {
            DetectorService.TestBinder binder = (DetectorService.TestBinder) service;
            detectorService = binder.getBoundService();

            detectorService.startVideoDetection();
            detectorService.debugVideoProcessing(inputImageView, outputImageView);
            detectorService.setOnDetectionListener(new DetectorService.OnDetectionListener() {
                @Override
                public void onDetection(@NonNull DetectionReport detectionReport) {
                    Log.d("onDetection", detectionReport.toString());
                }
            });
        }
        @Override
        public void onServiceDisconnected(ComponentName name) {}
    };
}